summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLubomir Rintel <lkundrak@v3.sk>2019-07-15 15:13:49 +0000
committerLubomir Rintel <lkundrak@v3.sk>2019-07-15 15:13:49 +0000
commitd94eeca417a794b967a84845fda95af204977b2a (patch)
tree295d963785fcbbb95800ce094f964374de541735
parent0a365d891d5ad2afac922e1a861d7d7d9089a9f9 (diff)
downloadNetworkManager-d94eeca417a794b967a84845fda95af204977b2a.tar.gz
x
-rw-r--r--src/supplicant/nm-supplicant-config.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/supplicant/nm-supplicant-config.c b/src/supplicant/nm-supplicant-config.c
index b5573536bc..fd09dc47e4 100644
--- a/src/supplicant/nm-supplicant-config.c
+++ b/src/supplicant/nm-supplicant-config.c
@@ -854,8 +854,10 @@ nm_supplicant_config_add_setting_wireless_security (NMSupplicantConfig *self,
}
}
- /* Don't try to enable PMF on non-WPA networks */
- if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk"))
+ /* Force PMF with SAE, disable it on non-WPA networks */
+ if (!strcmp (key_mgmt, "sae"))
+ pmf = NM_SETTING_WIRELESS_SECURITY_PMF_REQUIRED;
+ else if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk"))
pmf = NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE;
/* Check if we actually support PMF */